@@ -41,7 +41,7 @@
 #undef LZO_HAVE_CONFIG_H
 #include "minilzo.h"
 
-#if !defined(MINILZO_VERSION) || (MINILZO_VERSION != 0x1030)
+#if !defined(MINILZO_VERSION) || (MINILZO_VERSION != 0x1040)
 #  error "version mismatch in miniLZO source files"
 #endif
 
@@ -178,9 +178,9 @@
 #if !defined(SIZEOF_UNSIGNED)
 #  if (UINT_MAX == 0xffff)
 #    define SIZEOF_UNSIGNED         2
-#  elif (UINT_MAX == 0xffffffffL)
+#  elif (UINT_MAX == LZO_0xffffffffL)
 #    define SIZEOF_UNSIGNED         4
-#  elif (UINT_MAX >= 0xffffffffL)
+#  elif (UINT_MAX >= LZO_0xffffffffL)
 #    define SIZEOF_UNSIGNED         8
 #  else
 #    error SIZEOF_UNSIGNED
@@ -188,9 +188,9 @@
 #endif
 
 #if !defined(SIZEOF_UNSIGNED_LONG)
-#  if (ULONG_MAX == 0xffffffffL)
+#  if (ULONG_MAX == LZO_0xffffffffL)
 #    define SIZEOF_UNSIGNED_LONG    4
-#  elif (ULONG_MAX >= 0xffffffffL)
+#  elif (ULONG_MAX >= LZO_0xffffffffL)
 #    define SIZEOF_UNSIGNED_LONG    8
 #  else
 #    error SIZEOF_UNSIGNED_LONG
@@ -204,11 +204,11 @@
 #  define SIZE_T_MAX                LZO_UTYPE_MAX(SIZEOF_SIZE_T)
 #endif
 
-#if 1 && defined(__LZO_i386) && (UINT_MAX == 0xffffffffL)
+#if 1 && defined(__LZO_i386) && (UINT_MAX == LZO_0xffffffffL)
 #  if !defined(LZO_UNALIGNED_OK_2) && (USHRT_MAX == 0xffff)
 #    define LZO_UNALIGNED_OK_2
 #  endif
-#  if !defined(LZO_UNALIGNED_OK_4) && (LZO_UINT32_MAX == 0xffffffffL)
+#  if !defined(LZO_UNALIGNED_OK_4) && (LZO_UINT32_MAX == LZO_0xffffffffL)
 #    define LZO_UNALIGNED_OK_4
 #  endif
 #endif
@@ -228,7 +228,7 @@
 #if defined(LZO_UNALIGNED_OK_2) && (USHRT_MAX != 0xffff)
 #  error "LZO_UNALIGNED_OK_2 must not be defined on this system"
 #endif
-#if defined(LZO_UNALIGNED_OK_4) && (LZO_UINT32_MAX != 0xffffffffL)
+#if defined(LZO_UNALIGNED_OK_4) && (LZO_UINT32_MAX != LZO_0xffffffffL)
 #  error "LZO_UNALIGNED_OK_4 must not be defined on this system"
 #endif
 
@@ -236,7 +236,7 @@
 #  undef LZO_ALIGNED_OK_4
 #endif
 
-#if defined(LZO_ALIGNED_OK_4) && (LZO_UINT32_MAX != 0xffffffffL)
+#if defined(LZO_ALIGNED_OK_4) && (LZO_UINT32_MAX != LZO_0xffffffffL)
 #  error "LZO_ALIGNED_OK_4 must not be defined on this system"
 #endif
 
@@ -340,7 +340,7 @@ extern "C" {
 #  endif
 #endif
 
-#if (UINT_MAX >= 0xffffffffL)
+#if (UINT_MAX >= LZO_0xffffffffL)
    typedef ptrdiff_t            lzo_ptrdiff_t;
 #else
    typedef long                 lzo_ptrdiff_t;
@@ -645,16 +645,16 @@ const lzo_byte __lzo_copyright[] =
 #ifdef __PIC__
     " __PIC__\n"
 #endif
-#if (UINT_MAX < 0xffffffffL)
+#if (UINT_MAX < LZO_0xffffffffL)
     " 16BIT\n"
 #endif
 #if defined(__LZO_STRICT_16BIT)
     " __LZO_STRICT_16BIT\n"
 #endif
-#if (UINT_MAX > 0xffffffffL)
+#if (UINT_MAX > LZO_0xffffffffL)
     " UINT_MAX=" _LZO_MEXPAND(UINT_MAX) "\n"
 #endif
-#if (ULONG_MAX > 0xffffffffL)
+#if (ULONG_MAX > LZO_0xffffffffL)
     " ULONG_MAX=" _LZO_MEXPAND(ULONG_MAX) "\n"
 #endif
 #if defined(LZO_BYTE_ORDER)
@@ -1119,7 +1119,7 @@ _lzo_config_check(void)
     if (r == 1)
     {
 #  if (LZO_BYTE_ORDER == LZO_LITTLE_ENDIAN)
-	lzo_uint32 a = (lzo_uint32) (u.a & 0xffffffffL);
+	lzo_uint32 a = (lzo_uint32) (u.a & LZO_0xffffffffL);
 	unsigned short b = (unsigned short) (u.b & 0xffff);
 	r &= __lzo_assert(a == 0x03020100L);
 	r &= __lzo_assert(b == 0x0100);
