@@ -326,7 +326,7 @@ _lzo_config_check(void)
 	if (r == 1)
 	{
 #  if (LZO_BYTE_ORDER == LZO_LITTLE_ENDIAN)
-		lzo_uint32 a = (lzo_uint32) (u.a & 0xffffffffL);
+		lzo_uint32 a = (lzo_uint32) (u.a & LZO_0xffffffffL);
 		unsigned short b = (unsigned short) (u.b & 0xffff);
 		r &= __lzo_assert(a == 0x03020100L);
 		r &= __lzo_assert(b == 0x0100);
